@@ -797,9 +797,8 @@ check_setup.reg <- function(
 
 #' @title Control MCMC fitting process
 #'
-#' @description Controls settings for the autofit
-#' process of the MCMC JAGS sampler (specifies termination
-#' criteria), and values for the convergence checks.
+#' @description \code{set_autofit_control} and \code{set_convergence_checks} control settings for the 
+#' autofit process of the MCMC JAGS sampler and specify termination criteria and convergence checks.
 #'
 #' @param max_Rhat maximum value of the R-hat diagnostic.
 #' Defaults to \code{1.05}.
@@ -827,7 +826,37 @@ check_setup.reg <- function(
 #' @param restarts number of times new initial values should be generated in case a
 #' model fails to initialize. Defaults to \code{10}.
 #' @param max_extend number of times after which the automatic fitting function is stopped.
+#' Defaults to \code{10}.
 #'
+#' @details
+#' \code{set_autofit_control} controls the automatic model fitting process, determining when to
+#' stop iterating based on convergence criteria. \code{set_convergence_checks} sets thresholds
+#' for determining whether a model has converged adequately.
+#'
+#' The autofit control manages computational resources by setting maximum time limits and 
+#' determining how many additional samples to draw if convergence criteria are not met.
+#' The convergence checks determine the quality standards that fitted models must meet.
+#'
+#' @examples
+#' # Set custom autofit control with shorter time limit
+#' autofit_ctrl <- set_autofit_control(
+#'   max_time = list(time = 30, unit = "mins"),
+#'   sample_extend = 2000
+#' )
+#' 
+#' # Set custom convergence checks with stricter criteria
+#' conv_checks <- set_convergence_checks(
+#'   max_Rhat = 1.01,
+#'   min_ESS = 1000
+#' )
+#' 
+#' \dontrun{
+#' # Use in RoBMA function
+#' fit <- RoBMA(d = c(0.5, 0.3, 0.1), 
+#'              se = c(0.2, 0.15, 0.1),
+#'              autofit_control = autofit_ctrl,
+#'              convergence_checks = conv_checks)
+#' }
 #'
 #' @return \code{set_autofit_control} returns a list of autofit control settings
 #' and \code{set_convergence_checks} returns a list of convergence checks settings.
@@ -835,9 +864,9 @@ check_setup.reg <- function(
 #' @export set_autofit_control
 #' @export set_convergence_checks
 #' @name RoBMA_control
-#' @aliases set_autofit_control, set_convergence_checks
+#' @aliases set_autofit_control set_convergence_checks
 #'
-#' @seealso [RoBMA], [update.RoBMA]
+#' @seealso [RoBMA()], [update.RoBMA()]
 NULL
 
 #' @rdname RoBMA_control
@@ -876,6 +905,13 @@ set_convergence_checks  <- function(max_Rhat = 1.05, min_ESS = 500, max_error =
 
 
 
+# Internal control parameter update functions:
+# Purpose: Merge user-specified parameters with existing control settings
+# Used for updating model fitting, convergence checking, and autofit parameters
+# LLM Note: These functions implement parameter inheritance for model updates
+
+# Update MCMC fitting control parameters:
+# Handles chains, adaptation, burnin, sampling parameters for JAGS
 .update_fit_control     <- function(old_fit_control, chains, adapt, burnin, sample, thin, autofit, parallel, cores, silent, seed){
 
   if(is.null(chains)){
@@ -1053,11 +1089,7 @@ set_convergence_checks  <- function(max_Rhat = 1.05, min_ESS = 500, max_error =
 
   warnings <- NULL
 
-  if(!is.null(object$data[["outcome"]])){
-    data <- object$data[["outcome"]]
-  }else{
-    data <- object[["data"]]
-  }
+  data <- .get_outcome_data(object)
 
   # check whether majority of effect sizes are in expected direction. throw warning if not.
   if(any(sapply(object$priors[["bias"]], function(p) p[["distribution"]]) == "one.sided") |
